# PulpContainerClient::RepositoriesContainerPushApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](RepositoriesContainerPushApi.md#list) | **GET** /pulp/api/v3/repositories/container/container-push/ | List container push repositorys
[**partial_update**](RepositoriesContainerPushApi.md#partial_update) | **PATCH** {container_container_push_repository_href} | Update a container push repository
[**read**](RepositoriesContainerPushApi.md#read) | **GET** {container_container_push_repository_href} | Inspect a container push repository
[**remove_image**](RepositoriesContainerPushApi.md#remove_image) | **POST** {container_container_push_repository_href}remove_image/ | Delete an image from a repository
[**tag**](RepositoriesContainerPushApi.md#tag) | **POST** {container_container_push_repository_href}tag/ | Create a Tag
[**untag**](RepositoriesContainerPushApi.md#untag) | **POST** {container_container_push_repository_href}untag/ | Delete a tag
[**update**](RepositoriesContainerPushApi.md#update) | **PUT** {container_container_push_repository_href} | Update a container push repository



## list

> PaginatedcontainerContainerPushRepositoryResponseList list(opts)

List container push repositorys

ViewSet for a container push repository.  POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerPushApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List container push repositorys
  result = api_instance.list(opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerPushApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedcontainerContainerPushRepositoryResponseList**](PaginatedcontainerContainerPushRepositoryResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(container_container_push_repository_href, patchedcontainer_container_push_repository)

Update a container push repository

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerPushApi.new
container_container_push_repository_href = 'container_container_push_repository_href_example' # String | 
patchedcontainer_container_push_repository = PulpContainerClient::PatchedcontainerContainerPushRepository.new # PatchedcontainerContainerPushRepository | 

begin
  #Update a container push repository
  result = api_instance.partial_update(container_container_push_repository_href, patchedcontainer_container_push_repository)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerPushApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_push_repository_href** | **String**|  | 
 **patchedcontainer_container_push_repository** | [**PatchedcontainerContainerPushRepository**](PatchedcontainerContainerPushRepository.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> ContainerContainerPushRepositoryResponse read(container_container_push_repository_href, opts)

Inspect a container push repository

ViewSet for a container push repository.  POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerPushApi.new
container_container_push_repository_href = 'container_container_push_repository_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a container push repository
  result = api_instance.read(container_container_push_repository_href, opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerPushApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_push_repository_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**ContainerContainerPushRepositoryResponse**](ContainerContainerPushRepositoryResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## remove_image

> AsyncOperationResponse remove_image(container_container_push_repository_href, remove_image)

Delete an image from a repository

Trigger an asynchronous task to remove a manifest and all its associated data by a digest

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerPushApi.new
container_container_push_repository_href = 'container_container_push_repository_href_example' # String | 
remove_image = PulpContainerClient::RemoveImage.new # RemoveImage | 

begin
  #Delete an image from a repository
  result = api_instance.remove_image(container_container_push_repository_href, remove_image)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerPushApi->remove_image: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_push_repository_href** | **String**|  | 
 **remove_image** | [**RemoveImage**](RemoveImage.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## tag

> AsyncOperationResponse tag(container_container_push_repository_href, tag_image)

Create a Tag

Trigger an asynchronous task to tag an image in the repository

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerPushApi.new
container_container_push_repository_href = 'container_container_push_repository_href_example' # String | 
tag_image = PulpContainerClient::TagImage.new # TagImage | 

begin
  #Create a Tag
  result = api_instance.tag(container_container_push_repository_href, tag_image)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerPushApi->tag: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_push_repository_href** | **String**|  | 
 **tag_image** | [**TagImage**](TagImage.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## untag

> AsyncOperationResponse untag(container_container_push_repository_href, un_tag_image)

Delete a tag

Trigger an asynchronous task to untag an image in the repository

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerPushApi.new
container_container_push_repository_href = 'container_container_push_repository_href_example' # String | 
un_tag_image = PulpContainerClient::UnTagImage.new # UnTagImage | 

begin
  #Delete a tag
  result = api_instance.untag(container_container_push_repository_href, un_tag_image)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerPushApi->untag: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_push_repository_href** | **String**|  | 
 **un_tag_image** | [**UnTagImage**](UnTagImage.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## update

> AsyncOperationResponse update(container_container_push_repository_href, container_container_push_repository)

Update a container push repository

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerPushApi.new
container_container_push_repository_href = 'container_container_push_repository_href_example' # String | 
container_container_push_repository = PulpContainerClient::ContainerContainerPushRepository.new # ContainerContainerPushRepository | 

begin
  #Update a container push repository
  result = api_instance.update(container_container_push_repository_href, container_container_push_repository)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerPushApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_push_repository_href** | **String**|  | 
 **container_container_push_repository** | [**ContainerContainerPushRepository**](ContainerContainerPushRepository.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

